@@ -6,11 +6,10 @@ import anndata as ad
 from scipy.sparse import csr_matrix
 import squidpy as sq
 from sklearn.mixture import GaussianMixture 
-from spatial_measure import Global_L, Local_L
+from .spatial_measure import Global_L, Local_L
 import numpy as np
 import seaborn as sns
 from matplotlib import pyplot as plt
-from modules import gmod
 
 def load_raw(self, count_path, meta_path , visium_path):
     if os.path.exists(visium_path):
@@ -221,9 +220,6 @@ def save_coexpr(self, path, use_grouped=False):
     else:
         self.co_expression.to_csv(path)
 
-def gene_modules(self, nmax=6, use_grouped=False, n_modules = None):
-    return gmod.genemodules(self, nmax=nmax, use_grouped=use_grouped, n_modules = n_modules)
-
 def module_pattern(self, ncols=4, alpha_img=0.5, cmap='Reds'):
     mod2gene = self.module_dict['mod2gene'].copy()
     modules = list(mod2gene.keys())
